@@ -7,6 +7,7 @@ from libacr import acr_zones, forms
 from libacr.lib import url, current_user_id, language, icons, user_can_modify
 from libacr.model.core import DBSession
 from libacr.model.content import Tag, Page, Slice, Content, ContentData
+from libacr.model.attributes import Attribute
 
 from tw.api import WidgetsList
 import tw.forms as widgets
@@ -44,7 +45,8 @@ class SlicesAdminController(BaseAdminController):
 
         prop_values = {'uid':slice.uid, 'name':slice.name, 'zone':slice.zone,
                        'page':slice.page and slice.page.uid,
-                       'tags':[tag.uid for tag in slice.tags]}
+                       'tags':[tag.uid for tag in slice.tags],
+                       'attributes':[dict(name=attr.name, value=attr.value) for attr in slice.attributes]}
 
         return dict(slice=slice, section_title="Slice Editing",
                     edit_slice_form=edit_slice_form, clone_slice_form=clone_slice_form,
@@ -61,13 +63,13 @@ class SlicesAdminController(BaseAdminController):
 
         slice.name = kw['name']
         slice.zone = kw['zone']
-        slice.tags = []
 
         if kw['page']:
             slice.page = DBSession.query(Page).get(kw['page'])
         else:
             slice.page = None
 
+        slice.tags = []        
         for tag_id in kw.get('tags', []):
             try:
                 tag = DBSession.query(Tag).filter_by(uid=tag_id).one()
@@ -75,6 +77,12 @@ class SlicesAdminController(BaseAdminController):
             except:
                 pass
 
+        slice.attributes = []
+        for attribute in kw.get('attributes', []):
+            name = attribute['name']
+            value = attribute['value']
+            DBSession.add(Attribute(name=name, value=value, slice=slice))
+
         flash('Slice Properties successfully updated')
         return redirect(url('/admin/slices/edit', uid=kw['uid']))
 
@@ -100,7 +108,9 @@ class SlicesAdminController(BaseAdminController):
         values.update(ViewsManager.decode(slice.view, cdata.value))
 
         return dict(slice=slice, translate_box=translate_box,
-                    edit_form=edit_form, values=values, revision=revision)
+                    edit_form=edit_form, values=values, revision=revision,
+                    action=url('/admin/slices/update_content'),
+                    translate_url='/admin/slices/edit_content')
             
     @expose()
     @require(predicates.in_group("acr"))
@@ -167,7 +177,7 @@ class SlicesAdminController(BaseAdminController):
             flash('You do not have permissions to edit this page', 'error')
             return redirect(url(page.url))
 
-        values = {'page':page.uid}        
+        values = {'page':page.uid, 'name':'%s-%s' % (view, datetime.now().strftime('%y%m%d%H%M%S'))}        
         create_form = ViewsManager.create_form(view, CreateContentForm)
         return dict(create_form=create_form, values=values)
 
@@ -199,4 +209,4 @@ class SlicesAdminController(BaseAdminController):
         DBSession.flush()
 
         flash('Slice successfully cloned')
-        return redirect(url('/admin/slices/edit', uid=new_slice.uid))
\ No newline at end of file
+        return redirect(url('/admin/slices/edit', uid=new_slice.uid))
