@@ -33,9 +33,8 @@ class GalleryController(BaseAdminController):
         node_args['order'] = 0
         node_args['tags'] = []
         node_args['view'] = 'slicegroup'
-        node_args['data'] = """[group]
-filter_tag=%s
-preview=1""" % tag.name
+        node_args['data'] = EncodedView().from_dict(dict(filter_tag=tag.name,
+                                                         preview=1))
         _create_node(**node_args)
 
         node_args['name'] += '_script'
