@@ -5,6 +5,7 @@ from libacr.lib import get_slices_with_tag, get_page_from_urllist
 import libacr.helpers as h
 import tw.forms as twf
 from tw.tinymce import TinyMCE, MarkupConverter
+from base import EncodedView
 
 class LinkRenderer(object):
     def __init__(self):
@@ -39,13 +40,16 @@ fontselect,fontsizeselect,separator,forecolor,backcolor"""))]
 
     def preview(self, page, slice, data):
         page = slice.page
-        link = acr_url('page', pageid=page.uid)
+        if page:
+            link = acr_url('/page', pageid=page.uid)
+        else:
+            link = acr_url('/slice', sliceid=slice.uid)
         text = slice.preview()
 
         result = '<div class="acr_preview">'
-        result += '<h1>%s</h1>' % (page and '<a href="%s">%s</a>' % (link, page.title) or page.title)
-        result += '<span>%s</span>' % slice.content.time.strftime('%Y-%m-%d %H:%M')
-        result += '<div>'+text+'</div>'
+        #result += '<h1>%s</h1>' % '<a href="%s">%s</a>' % (link, page and page.title or slice.name)
+        result += ' <span>%s</span>' % slice.content.time.strftime('%Y-%m-%d %H:%M')
+        result += ' <div>'+text+'</div>'
         result += '</div>'
 
         return result
@@ -56,6 +60,53 @@ fontselect,fontsizeselect,separator,forecolor,backcolor"""))]
     def from_dict(self, dic):
         return dic['data']
 
+class BlogPostRenderer(EncodedView):
+    def __init__(self):
+        self.name = 'blogpost'
+        self.exposed = True
+
+        self.form_fields = [twf.TextField('title', label_text="Title:", validator=twf.validators.String(not_empty=True, strip=True)),
+                            TinyMCE('content', label_text="", validator=MarkupConverter(),
+                                            rows=20, attrs={'style':'width:100%;height:400px;'},
+                                            mce_options=dict(theme_advanced_buttons1= """bold,italic,underline,
+strikethrough,separator,justifyleft,justifycenter,justifyright,justifyfull,separator,
+fontselect,fontsizeselect,separator,forecolor,backcolor"""))]
+
+        self.template = MarkupTemplate(u'''
+<html xmlns:py="http://genshi.edgewall.org/" py:strip="">
+    <h2><a py:strip="not link" href="${link}">${title}</a></h2>
+    <div class="post_info">${author} - ${date}</div>
+    <div class="post_content">
+        ${content}
+    </div>
+</html>''')
+
+    def render(self, page, slice, data):
+        data = self.to_dict(data)
+
+        try:
+            t = self.template.generate(title=data['title'], content=data['content'], link=None,
+                                       author=slice.content.data_instance.author,
+                                       date=slice.content.data_instance.time.strftime('%Y-%m-%d %H:%M'))
+            return t.render('xhtml').decode('utf-8')
+        except Exception, e:
+            return str(e)
+
+    def preview(self, page, slice, data):
+        page = slice.page
+        if page:
+            link = page.url
+        else:
+            link = acr_url('/slice', sliceid=slice.uid)
+
+        data = self.to_dict(data)
+        text = slice.preview(data=data['content'], omit_link=True)
+
+        t = self.template.generate(title=data['title'], content=text, link=link,
+                                   author=slice.content.data_instance.author,
+                                   date=slice.content.data_instance.time.strftime('%Y-%m-%d %H:%M'))
+        return t.render('xhtml').decode('utf-8')
+
 class GenshiRenderer(object):
     def __init__(self):
         self.name = 'genshi'
